@@ -1,6 +1,8 @@
-from xkcd import Client
+from xkcd import xkcd
 
-__version__ = '2.1.0'
+Client = xkcd
+
+__version__ = '2.5.0'
 __author__ = "Sasen Perera"
 __shot_des__ = "A python wrapper for xkcd.com"
 __description__ = "A wrapper for xkcd.com's API. Built Using Python."
\ No newline at end of file
